@@ -9,18 +9,59 @@
 #
 package Dist::Zilla::Plugin::NoSmartCommentsTests;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.006-7-g2f1f2a7
-$Dist::Zilla::Plugin::NoSmartCommentsTests::VERSION = '0.007';
+# git description: 0.008-9-g4f29d74
+$Dist::Zilla::Plugin::NoSmartCommentsTests::VERSION = '0.009';
 
 # ABSTRACT: Make sure no Smart::Comments escape into the wild
 
 use Moose;
 use namespace::autoclean;
+use MooseX::AttributeShortcuts;
+
+use autobox::Core;
 
 extends 'Dist::Zilla::Plugin::InlineFiles';
 
+with
+    'Dist::Zilla::Role::FileFinderUser' => {
+        default_finders => [qw { :InstallModules :ExecFiles :TestFiles }],
+    },
+    'Dist::Zilla::Role::TextTemplate',
+    'Dist::Zilla::Role::PrereqSource',
+    ;
+
+
+sub register_prereqs {
+    my $self = shift @_;
+
+    $self->zilla->register_prereqs(
+        { phase => 'develop' },
+        'Test::NoSmartComments' => 0,
+    );
+
+    return;
+}
+
+around merged_section_data => sub {
+    my ($orig, $self) = (shift, shift);
+
+    ### invoke the original to get the sections...
+    my $data = $self->$orig(@_);
+
+    ### bail if no data...
+    return unless $data;
+
+    ### munge each section with our template engine...
+    my %stash = ( files => [ map { $_->name } $self->found_files->flatten ] );
+    do { $data->{$_} = \( $self->fill_in_string(${$data->{$_}}, { %stash }) ) }
+        for $data->keys;
+
+    ### $data
+    return $data;
+};
+
 __PACKAGE__->meta->make_immutable;
-1;
+!!42;
 
 =pod
 
@@ -36,13 +77,12 @@ Dist::Zilla::Plugin::NoSmartCommentsTests - Make sure no Smart::Comments escape
 
 =head1 VERSION
 
-This document describes version 0.007 of Dist::Zilla::Plugin::NoSmartCommentsTests - released December 02, 2014 as part of Dist-Zilla-Plugin-NoSmartCommentsTests.
+This document describes version 0.009 of Dist::Zilla::Plugin::NoSmartCommentsTests - released October 09, 2016 as part of Dist-Zilla-Plugin-NoSmartCommentsTests.
 
 =head1 SYNOPSIS
 
-In C<dist.ini>:
-
-    [NoSmartCommentsTests]
+    ; In C<dist.ini>:
+    [Test::NoSmartComments]
 
 =head1 DESCRIPTION
 
@@ -51,25 +91,19 @@ following file:
 
   xt/release/no-smart-comments.t - test to ensure no Smart::Comments
 
+=head1 METHODS
+
+=head2 register_prereqs
+
+Registers a 'develop' phase requirement for L<Test::NoSmartComments> with the
+L<Dist::Zilla> object.
+
 =head1 NOTE
 
 The name of this plugin has turned out to be somewhat misleading, I'm afraid:
 we don't actually test for the _existance_ of smart comments, rather we
 ensure that Smart::Comment is not used by any file checked.
 
-=head1 BUGS
-
-All complex software has bugs lurking in it, and this module is no exception.
-
-Please report any bugs to
-"bug-dist-zilla-plugin-nosmartcommentstests@rt.cpan.org", or through the web
-interface at <http://rt.cpan.org>.
-
-Patches and pull requests through GitHub are most welcome; our page and repo
-(same URI):
-
-    https://github.com/RsrchBoy/dist-zilla-plugin-nosmartcommentstests
-
 =head1 SEE ALSO
 
 Please see those modules/websites for more information related to this module.
@@ -78,19 +112,18 @@ Please see those modules/websites for more information related to this module.
 
 =item *
 
-L<Smart::Comments>, L<Test::NoSmartComments>
+L<Smart::Comments|Smart::Comments>
+
+=item *
+
+L<Test::NoSmartComments|Test::NoSmartComments>
 
 =back
 
-=head1 SOURCE
-
-The development version is on github at L<http://https://github.com/RsrchBoy/dist-zilla-plugin-nosmartcommentstests>
-and may be cloned from L<git://https://github.com/RsrchBoy/dist-zilla-plugin-nosmartcommentstests.git>
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/RsrchBoy/dist-zilla-plugin-nosmartcommentstests/issues
+L<https://github.com/RsrchBoy/dist-zilla-plugin-nosmartcommentstests/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -104,7 +137,7 @@ Chris Weyl <cweyl@alumni.drew.edu>
 
 =begin html
 
-<a href="https://www.gittip.com/RsrchBoy/"><img src="https://raw.githubusercontent.com/gittip/www.gittip.com/master/www/assets/%25version/logo.png" /></a>
+<a href="https://gratipay.com/RsrchBoy/"><img src="http://img.shields.io/gratipay/RsrchBoy.svg" /></a>
 <a href="http://bit.ly/rsrchboys-wishlist"><img src="http://wps.io/wp-content/uploads/2014/05/amazon_wishlist.resized.png" /></a>
 <a href="https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fdist-zilla-plugin-nosmartcommentstests&title=RsrchBoy's%20CPAN%20Dist-Zilla-Plugin-NoSmartCommentsTests&tags=%22RsrchBoy's%20Dist-Zilla-Plugin-NoSmartCommentsTests%20in%20the%20CPAN%22"><img src="http://api.flattr.com/button/flattr-badge-large.png" /></a>
 
@@ -115,9 +148,9 @@ rather B<it is simply a very pleasant surprise>. I largely create and release
 works like this because I need them or I find it enjoyable; however, don't let
 that stop you if you feel like it ;)
 
-L<Flattr this|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fdist-zilla-plugin-nosmartcommentstests&title=RsrchBoy's%20CPAN%20Dist-Zilla-Plugin-NoSmartCommentsTests&tags=%22RsrchBoy's%20Dist-Zilla-Plugin-NoSmartCommentsTests%20in%20the%20CPAN%22>,
-L<gittip me|https://www.gittip.com/RsrchBoy/>, or indulge my
-L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If you so desire.
+L<Flattr|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fdist-zilla-plugin-nosmartcommentstests&title=RsrchBoy's%20CPAN%20Dist-Zilla-Plugin-NoSmartCommentsTests&tags=%22RsrchBoy's%20Dist-Zilla-Plugin-NoSmartCommentsTests%20in%20the%20CPAN%22>,
+L<Gratipay|https://gratipay.com/RsrchBoy/>, or indulge my
+L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If and *only* if you so desire.
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -142,7 +175,5 @@ eval "use Test::NoSmartComments";
 plan skip_all => 'Test::NoSmartComments required for checking comment IQ'
     if $@;
 
-no_smart_comments_in_all();
-no_smart_comments_in_tests();
-
+{{ foreach my $file (@files) { $OUT .= qq{no_smart_comments_in("$file");\n} } }}
 done_testing();
